==> eam-wshub-proxyclient-11.4-9-sources.jar: net/datastream/schemas/mp_functions/gridrequest/ADDON_FILTER.java <==

package net.datastream.schemas.mp_functions.gridrequest;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="ALIAS_NAME" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="OPERATOR" type="{http://schemas.datastream.net/MP_functions/GridRequest}OPERATOR_TYPE" />
 *       &lt;attribute name="VALUE" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "ADDON_FILTER")
public class ADDON_FILTER {

    @XmlAttribute(name = "ALIAS_NAME")
    protected String alias_NAME;
    @XmlAttribute(name = "OPERATOR")
    protected String operator;
    @XmlAttribute(name = "VALUE")
    protected String value;

    /**
     * Obtient la valeur de la propriété alias_NAME.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALIAS_NAME() {
        return alias_NAME;
    }

    /**
     * Définit la valeur de la propriété alias_NAME.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALIAS_NAME(String value) {
        this.alias_NAME = value;
    }

    /**
     * Obtient la valeur de la propriété operator.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOPERATOR() {
        return operator;
    }

    /**
     * Définit la valeur de la propriété operator.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOPERATOR(String value) {
        this.operator = value;
    }

    /**
     * Obtient la valeur de la propriété value.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVALUE() {
        return value;
    }

    /**
     * Définit la valeur de la propriété value.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVALUE(String value) {
        this.value = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_functions/gridrequest/ADDON_FILTER.java <==

package net.datastream.schemas.mp_functions.gridrequest;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="ALIAS_NAME" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="OPERATOR" type="{http://schemas.datastream.net/MP_functions/GridRequest}OPERATOR_TYPE" />
 *       &lt;attribute name="VALUE" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "ADDON_FILTER")
public class ADDON_FILTER {

    @XmlAttribute(name = "ALIAS_NAME")
    protected String alias_NAME;
    @XmlAttribute(name = "OPERATOR")
    protected String operator;
    @XmlAttribute(name = "VALUE")
    protected String value;

    /**
     * Gets the value of the alias_NAME property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALIAS_NAME() {
        return alias_NAME;
    }

    /**
     * Sets the value of the alias_NAME property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALIAS_NAME(String value) {
        this.alias_NAME = value;
    }

    /**
     * Gets the value of the operator property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOPERATOR() {
        return operator;
    }

    /**
     * Sets the value of the operator property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOPERATOR(String value) {
        this.operator = value;
    }

    /**
     * Gets the value of the value property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVALUE() {
        return value;
    }

    /**
     * Sets the value of the value property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVALUE(String value) {
        this.value = value;
    }

}
